@@ -135,7 +135,7 @@ class Group(repops.MultiOpRep):
         #filter flattened slices 
         gidx = range(len(gsource._slices))
         gdims = gslice.dims[-len(gsource._slices):]
-        firstelem = python.Rep(0)._slices[0]
+        firstelem = python.Rep(0,name="data")._slices[0]
         for key, pos in xflat.iteritems():
             tslice = gslice
             for elem in gidx:
@@ -251,7 +251,7 @@ class Unique(repops.MultiOpRep):
                 constraint = repops.PlusPrefix(python.Rep(constraint,name="filter"))
             repops.MultiOpRep.__init__(self,(source,constraint),descend=descend)
 
-    def _sprocess(self, sources, descend):
+    def _process(self, sources, descend):
         if(len(sources) == 1): #no explicit constraint, use data itself
             source = sources[0]
             if len(source._slices) > 1:
@@ -260,6 +260,8 @@ class Unique(repops.MultiOpRep):
                 constraint = source
         else:
             source,constraint = sources 
+        if not source._slicesKnown() or not constraint._typesKnown():
+            return
 
         if len(constraint._slices) > 1:
             constraint = constraint.Tuple()
@@ -426,10 +428,12 @@ class Replace(repops.MultiOpRep):
 
 
 class Take(repops.MultiOpRep):
-    def __init__(self, source, take_source, allow_missing=False):
-        repops.MultiOpRep.__init__(self,(source, take_source), allow_missing = allow_missing)
+    def __init__(self, source, take_source, allow_missing=False, keep_missing=False):
+        if (isinstance(source,dict)):
+             source = python.Rep(list(source.iteritems()),name="data").IndexDict()
+        repops.MultiOpRep.__init__(self,(source, take_source), allow_missing = allow_missing, keep_missing=keep_missing)
    
-    def _sprocess(self, sources, allow_missing):
+    def _sprocess(self, sources, allow_missing,keep_missing):
         source, take_source = sources
         if len(source._slices) == 2:
             source = source.IndexDict()
@@ -438,7 +442,7 @@ class Take(repops.MultiOpRep):
 
         nslices = []
         for take_slice in take_source._slices:
-            nslices.append(ops.TakeOp(source_slice, take_slice, allow_missing))
+            nslices.append(ops.TakeOp(source_slice, take_slice, allow_missing, keep_missing))
         return self._initialize(tuple(nslices))
 
 
