@@ -90,7 +90,7 @@ class Project(repops.UnaryOpRep):
                                nelem = [slice for slice in cur_slices if elem in slice.bookmarks]
                                assert len(nelem) > 0, "Could not find (unique) matching slice/bookmark for name: " + elem
                         else:
-                            assert len(nelem) ==1, "Could not find (unique) matching slice for name: " + elem
+                            assert len(nelem) > 0, "Could not find (unique) matching slice for name: " + elem
                     elem = nelem
                 elif(isinstance(elem, representor.Representor)):
                     pass
@@ -103,7 +103,7 @@ class Project(repops.UnaryOpRep):
                         elem = self._source.Get(*elem).Array()
                 else:
                     elem = util.select(cur_slices, elem)
-
+                   
                 project_sources.append((name,elem))
             self._project_sources = project_sources
      
@@ -206,7 +206,7 @@ class Bookmark(repops.UnaryOpRep):
             nnslices = []
             for slice in source._slices:
                 if(slice.dims[0].name in kwds):
-                    nslice = slice.ChangeBookmarkOp(slice,kdws[slice.dims[0].name])
+                    nslice = slice.ChangeBookmarkOp(slice,kwds[slice.dims[0].name])
                 else:
                     nslice = slice
                 nnslices.append(nslice)
@@ -227,7 +227,7 @@ class SliceRename(repops.UnaryOpRep):
             nslices = []
             for slice in source._slices:
                 if(slice.name in kwds):
-                    nslice = ops.ChangeNameOp(slice,kdws[slice.name])
+                    nslice = ops.ChangeNameOp(slice,kwds[slice.name])
                 else:
                     nslice = slice
                 nslices.append(nslice)
