@@ -10,6 +10,7 @@ import os.path
 import gc, sys
 import itertools
 import csv
+import cutils
 
 
 #objs: objs to find names for
@@ -393,3 +394,60 @@ class memoized(object):
        """Support instance methods."""
        return functools.partial(self.__call__, obj)
 
+def check_realseq(data):
+    return isinstance(data,collections.Sequence) and not isinstance(data, basestring)
+
+def get_shape(data, lengths, pos=0):
+    if check_realseq(data):
+        if len(lengths) > pos + 1 and len(lengths[pos + 1]) <= 1:
+            for elem in data:
+                if not get_shape(elem,lengths,pos+1):
+                    break
+        lengths[pos].add(len(data))
+    else:
+        lengths[pos].add(0)
+    return len(lengths[pos]) == 1
+
+def fill(data, x, pos):
+    if pos > 1:
+        for i in range(x.shape[0]):
+            fill(data[i],x[i,...],pos-1)
+    else:
+        x[:] = data
+
+def replace_darray(data, type=object, maxdim=1, mindim=0):
+    try:
+        return cutils.darray(data,type,maxdim,mindim)
+    except ValueError:
+        if maxdim == 1:
+            if not check_realseq(data):
+                if mindim == 0:  return data
+                else: raise ValueError, "Object not deep enough"
+            else:
+                nlen = len(data)
+                x = numpy.zeros((nlen,),dtype=type)
+                x[:] = data
+                return x
+        #maxdim > 1        
+        lengths = [set() for i in range(maxdim)]
+        get_shape(data, lengths)
+        cusedim = 0
+        for lg in lengths:
+            if len(lg) == 1:
+                cusedim = cusedim + 1
+        if cusedim < mindim:
+            raise ValueError, "Object not deep enough"
+        shape = [lengths[i].pop() for i in range(cusedim)]
+        x = numpy.zeros(tuple(shape),dtype=type)
+        fill(data,x, len(x.shape))
+        return x
+        
+
+nversion = numpy.__version__.split('.')    
+wrong_numpy = int(nversion[0]) >= 1 and int(nversion[1]) >= 6
+
+if wrong_numpy:
+    darray = replace_darray
+else:
+    darray = cutils.darray
+    
